@@ -39,6 +39,8 @@ static void _http_queue_send_stream(server_s *server, bool stream_updated, bool
 
 static bool _expose_new_frame(server_s *server);
 
+static char *_http_get_client_hostport(struct evhttp_request *request);
+
 
 #define RUN(_next)		server->run->_next
 #define STREAM(_next)	RUN(stream->_next)
@@ -49,7 +51,7 @@ static bool _expose_new_frame(server_s *server);
 server_s *server_init(stream_s *stream) {
 	exposed_s *exposed;
 	A_CALLOC(exposed, 1);
-	exposed->frame = frame_init("http_exposed");
+	exposed->frame = frame_init();
 
 	server_runtime_s *run;
 	A_CALLOC(run, 1);
@@ -91,12 +93,11 @@ void server_destroy(server_s *server) {
 	libevent_global_shutdown();
 #	endif
 
-	for (stream_client_s *client = RUN(stream_clients); client != NULL;) {
-		stream_client_s *next = client->next;
+	LIST_ITERATE(RUN(stream_clients), client, {
 		free(client->key);
+		free(client->hostport);
 		free(client);
-		client = next;
-	}
+	});
 
 	if (RUN(auth_token)) {
 		free(RUN(auth_token));
@@ -142,16 +143,14 @@ int server_listen(server_s *server) {
 	evhttp_set_timeout(RUN(http), server->timeout);
 
 	if (server->user[0] != '\0') {
-		char *raw_token;
 		char *encoded_token = NULL;
 
-		A_CALLOC(raw_token, strlen(server->user) + strlen(server->passwd) + 16);
-		sprintf(raw_token, "%s:%s", server->user, server->passwd);
+		char *raw_token;
+		A_ASPRINTF(raw_token, "%s:%s", server->user, server->passwd);
 		base64_encode((uint8_t *)raw_token, strlen(raw_token), &encoded_token, NULL);
 		free(raw_token);
 
-		A_CALLOC(RUN(auth_token), strlen(encoded_token) + 16);
-		sprintf(RUN(auth_token), "Basic %s", encoded_token);
+		A_ASPRINTF(RUN(auth_token), "Basic %s", encoded_token);
 		free(encoded_token);
 
 		LOG_INFO("Using HTTP basic auth");
@@ -366,9 +365,9 @@ static void _http_callback_state(struct evhttp_request *request, void *v_server)
 		RUN(stream_clients_count)
 	));
 
-	for (stream_client_s * client = RUN(stream_clients); client != NULL; client = client->next) {
+	LIST_ITERATE(RUN(stream_clients), client, {
 		assert(evbuffer_add_printf(buf,
-			"\"%s\": {\"fps\": %u, \"extra_headers\": %s, \"advance_headers\": %s,"
+			"\"%" PRIx64 "\": {\"fps\": %u, \"extra_headers\": %s, \"advance_headers\": %s,"
 			" \"dual_final_frames\": %s, \"zero_data\": %s}%s",
 			client->id,
 			client->fps,
@@ -378,7 +377,7 @@ static void _http_callback_state(struct evhttp_request *request, void *v_server)
 			bool_to_string(client->zero_data),
 			(client->next ? ", " : "")
 		));
-	}
+	});
 
 	assert(evbuffer_add_printf(buf, "}}}}"));
 
@@ -473,20 +472,10 @@ static void _http_callback_stream(struct evhttp_request *request, void *v_server
 #		undef PARSE_PARAM
 		evhttp_clear_headers(&params);
 
-		uuid_t uuid;
-		uuid_generate(uuid);
-		uuid_unparse_lower(uuid, client->id);
+		client->hostport = _http_get_client_hostport(request);
+		client->id = get_now_id();
 
-		if (RUN(stream_clients) == NULL) {
-			RUN(stream_clients) = client;
-		} else {
-			stream_client_s *last = RUN(stream_clients);
-
-			for (; last->next != NULL; last = last->next);
-			client->prev = last;
-			last->next = client;
-		}
-		RUN(stream_clients_count) += 1;
+		LIST_APPEND_C(RUN(stream_clients), client, RUN(stream_clients_count));
 
 		if (RUN(stream_clients_count) == 1) {
 			atomic_store(&VID(has_clients), true);
@@ -495,23 +484,18 @@ static void _http_callback_stream(struct evhttp_request *request, void *v_server
 #			endif
 		}
 
-		char *client_addr;
-		unsigned short client_port;
-		evhttp_connection_get_peer(conn, &client_addr, &client_port);
-
-		LOG_INFO("HTTP: Registered client: [%s]:%u, id=%s; clients now: %u",
-			client_addr, client_port, client->id, RUN(stream_clients_count));
-
+		LOG_INFO("HTTP: Registered client: %s, id=%" PRIx64 "; clients now: %u",
+			client->hostport, client->id, RUN(stream_clients_count));
 
 		struct bufferevent *buf_event = evhttp_connection_get_bufferevent(conn);
 		if (server->tcp_nodelay && !RUN(unix_fd)) {
 			evutil_socket_t fd;
 			int on = 1;
 
-			LOG_DEBUG("HTTP: Setting up TCP_NODELAY to the client [%s]:%u ...", client_addr, client_port);
+			LOG_DEBUG("HTTP: Setting up TCP_NODELAY to the client %s ...", client->hostport);
 			assert((fd = bufferevent_getfd(buf_event)) >= 0);
 			if (setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (void *)&on, sizeof(on)) != 0) {
-				LOG_PERROR("HTTP: Can't set TCP_NODELAY to the client [%s]:%u", client_addr, client_port);
+				LOG_PERROR("HTTP: Can't set TCP_NODELAY to the client %s", client->hostport);
 			}
 		}
 		bufferevent_setcb(buf_event, NULL, NULL, _http_callback_stream_error, (void *)client);
@@ -525,7 +509,6 @@ static void _http_callback_stream(struct evhttp_request *request, void *v_server
 
 static void _http_callback_stream_write(struct bufferevent *buf_event, void *v_client) {
 #	define BOUNDARY "boundarydonotcross"
-#	define RN "\r\n"
 
 	stream_client_s *client = (stream_client_s *)v_client;
 	server_s *server = client->server;
@@ -575,7 +558,7 @@ static void _http_callback_stream_write(struct bufferevent *buf_event, void *v_c
 			"Cache-Control: no-store, no-cache, must-revalidate, proxy-revalidate, pre-check=0, post-check=0, max-age=0" RN
 			"Pragma: no-cache" RN
 			"Expires: Mon, 3 Jan 2000 12:34:56 GMT" RN
-			"Set-Cookie: stream_client=%s/%s; path=/; max-age=30" RN
+			"Set-Cookie: stream_client=%s/%" PRIx64 "; path=/; max-age=30" RN
 			"Content-Type: multipart/x-mixed-replace;boundary=" BOUNDARY RN
 			RN
 			"--" BOUNDARY RN,
@@ -650,7 +633,6 @@ static void _http_callback_stream_write(struct bufferevent *buf_event, void *v_c
 	bufferevent_enable(buf_event, EV_READ);
 
 #	undef ADD_ADVANCE_HEADERS
-#	undef RN
 #	undef BOUNDARY
 }
 
@@ -658,10 +640,7 @@ static void _http_callback_stream_error(UNUSED struct bufferevent *buf_event, UN
 	stream_client_s *client = (stream_client_s *)v_client;
 	server_s *server = client->server;
 
-	char *reason = bufferevent_my_format_reason(what);
-
-	assert(RUN(stream_clients_count) > 0);
-	RUN(stream_clients_count) -= 1;
+	LIST_REMOVE_C(RUN(stream_clients), client, RUN(stream_clients_count));
 
 	if (RUN(stream_clients_count) == 0) {
 		atomic_store(&VID(has_clients), false);
@@ -670,40 +649,26 @@ static void _http_callback_stream_error(UNUSED struct bufferevent *buf_event, UN
 #		endif
 	}
 
-	char *client_addr = "???";
-	unsigned short client_port = 0;
+	char *reason = bufferevent_my_format_reason(what);
+	LOG_INFO("HTTP: Disconnected client: %s, id=%" PRIx64 ", %s; clients now: %u",
+		client->hostport, client->id, reason, RUN(stream_clients_count));
+	free(reason);
 
 	struct evhttp_connection *conn = evhttp_request_get_connection(client->request);
-	if (conn) {
-		evhttp_connection_get_peer(conn, &client_addr, &client_port);
-	}
-
-	LOG_INFO("HTTP: Disconnected client: [%s]:%u, id=%s, %s; clients now: %u",
-		client_addr, client_port, client->id, reason, RUN(stream_clients_count));
-
 	if (conn) {
 		evhttp_connection_free(conn);
 	}
 
-	if (client->prev == NULL) {
-		RUN(stream_clients) = client->next;
-	} else {
-		client->prev->next = client->next;
-	}
-	if (client->next != NULL) {
-		client->next->prev = client->prev;
-	}
 	free(client->key);
+	free(client->hostport);
 	free(client);
-
-	free(reason);
 }
 
 static void _http_queue_send_stream(server_s *server, bool stream_updated, bool frame_updated) {
 	bool has_clients = false;
 	bool queued = false;
 
-	for (stream_client_s *client = RUN(stream_clients); client != NULL; client = client->next) {
+	LIST_ITERATE(RUN(stream_clients), client, {
 		struct evhttp_connection *conn = evhttp_request_get_connection(client->request);
 		if (conn) {
 			// Фикс для бага WebKit. При включенной опции дропа одинаковых фреймов,
@@ -734,7 +699,7 @@ static void _http_queue_send_stream(server_s *server, bool stream_updated, bool
 
 			has_clients = true;
 		}
-	}
+	});
 
 	if (queued) {
 		static unsigned queued_fps_accum = 0;
@@ -836,3 +801,37 @@ static bool _expose_new_frame(server_s *server) {
 #undef VID
 #undef STREAM
 #undef RUN
+
+static char *_http_get_client_hostport(struct evhttp_request *request) {
+	char *addr = NULL;
+	unsigned short port = 0;
+	struct evhttp_connection *conn = evhttp_request_get_connection(request);
+	if (conn) {
+		char *peer;
+		evhttp_connection_get_peer(conn, &peer, &port);
+		assert(addr = strdup(peer));
+	}
+
+	const char *xff = evhttp_find_header(evhttp_request_get_input_headers(request), "X-Forwarded-For");
+	if (xff) {
+		if (addr) {
+			free(addr);
+		}
+		assert(addr = strndup(xff, 1024));
+		for (unsigned index = 0; addr[index]; ++index) {
+			if (addr[index] == ',') {
+				addr[index] = '\0';
+				break;
+			}
+		}
+	}
+
+	if (addr == NULL) {
+		assert(addr = strdup("???"));
+	}
+
+	char *hostport;
+	A_ASPRINTF(hostport, "[%s]:%u", addr, port);
+	free(addr);
+	return hostport;
+}
